summaryrefslogtreecommitdiff
path: root/rpmio/rpmpgp.h
diff options
context:
space:
mode:
Diffstat (limited to 'rpmio/rpmpgp.h')
-rw-r--r--rpmio/rpmpgp.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/rpmio/rpmpgp.h b/rpmio/rpmpgp.h
index 05d238c54..04e37688c 100644
--- a/rpmio/rpmpgp.h
+++ b/rpmio/rpmpgp.h
@@ -1196,11 +1196,12 @@ int pgpPrtComment(pgpTag tag, const byte *h, unsigned int hlen)
/*@modifies fileSystem @*/;
/**
- * Print/parse a single OpenPGP packet.
+ * Print/parse next OpenPGP packet.
* @param pkt OpenPGP packet
* @return -1 on error, otherwise packet length
*/
-int pgpPrtPkt(const byte *pkt)
+int pgpPrtPkt(const byte *pkt, unsigned int pleft)
/*@globals fileSystem @*/
/*@modifies fileSystem @*/;
/*@=exportlocal@*/
@@ -1208,12 +1209,12 @@ int pgpPrtPkt(const byte *pkt)
/**
* Print/parse a OpenPGP packet(s).
* @param pkts OpenPGP packet(s)
* @param plen packet(s) length (no. of bytes)
* @retval dig parsed output of signature/pubkey packet parameters
* @param printing should packets be printed?
* @return -1 on error, 0 on success
*/
-int pgpPrtPkts(const byte *pkts, unsigned int plen, pgpDig dig, int printing)
+int pgpPrtPkts(const byte *pkts, unsigned int pktlen, pgpDig dig, int printing)
/*@globals fileSystem @*/
/*@modifies fileSystem @*/;
@@ -1196,11 +1196,12 @@ int pgpPrtComment(pgpTag tag, const byte *h, unsigned int hlen)
* @param pkt OpenPGP packet
- * @return -1 on error, otherwise packet length
+ * @param pleft no. bytes remaining
+ * @return -1 on error, otherwise this packet length
*/
@@ -1208,12 +1209,12 @@ int pgpPrtPkt(const byte *pkt)
* Print/parse a OpenPGP packet(s).
* @param pkts OpenPGP packet(s)
- * @param plen packet(s) length (no. of bytes)
+ * @param pktlen OpenPGP packet(s) length (no. of bytes)
* @retval dig parsed output of signature/pubkey packet parameters
* @param printing should packets be printed?